==> zither-1.1.11.tar.gz: zither_prj/zither/prototype.h <==
// prototype.h
// $Id: prototype.h,v 1.5 2007/11/06 12:27:17 sendan Exp $
// masashi shimakura

#ifdef POSTGRES_IN
int pqconnect(void);
int pqexec_datain(char *);
int pqexec_select(char *);
int pg_connectset(private_data_t *, char *);
#endif

int socket_bind(struct sockaddr_in *, int, char *, int *);
int socket_accept(struct sockaddr_in *, int *, int *); 
// int socket_send(int, char *, int);
// int socket_send_bat(int, char *, int);
// int socket_send_client(int, char *, int);
// char * select_fdcat(int, char *, int *, int, int);

int malloc_set(void);
int malloc_set2(void);
int private_malloc_set(private_data_t *);
int private_malloc_free(private_data_t *);

int optin(int, char *[]);

int conf_set(char *);
int print_conf(void);
int set_data(void);
int client_set(private_data_t *);
int client_setg(private_data_t *);
int file_sets(private_data_t *, char);
int file_sets2(private_data_t *, char, int, int);

int start_neg(private_data_t *);
int stag_neg(private_data_t *);

int lockfile_remove(char *, char *, char *);
int neg(char *, char *, unsigned char *);
char * chack_lockfile(char *, char *, char *, char *, int *);
int lock_remove(char *);

char * file_send(int, char *, char *, int *, int, char);
char * file_send2(int, char *, char *, int *, int, char);
// char * diff_send(int, char *, char *, int *, int);
// int log_out(int, char *, char *, char *, unsigned char *);
int log_out2(int, char *, char *, char *, char *, unsigned char *);
int fd_outopen(char *, FILE *);
int put_log(char *, char *, char*, unsigned char *);
int put_log2(int, char *, char*, unsigned char *);
char * filename_create(char *, char *, char *, char *);

int time_getr(char [], int);
long int u_time(void);
int mail_time_getr(char [], int, char *);
int ctime_getr(char);

int mail_grsend( char *, char *, char *, char *, char *, char *, char *, char *, char *);

int life_check(private_data_t *);

char * stat_check(char *, char *, int, int *);

==> zither-1.1.14.tar.gz: zither_prj/zither/prototype.h <==
// prototype.h
// $Id: prototype.h,v 1.5 2007/11/06 12:27:17 sendan Exp $
// masashi shimakura

#ifdef POSTGRES_IN
int pqconnect(void);
int pqexec_datain(char *);
int pqexec_select(char *);
int pg_connectset(private_data_t *, char *);
#endif

// int socket_bind(struct sockaddr_in *, int, char *, int *);
// int socket_accept(struct sockaddr_in *, int *, int *); 

int malloc_set(void);
int malloc_set2(void);
int private_malloc_set(private_data_t *);
int private_malloc_free(private_data_t *);

int optin(int, char *[]);

int conf_set(char *);
int print_conf(void);
int set_data(void);
int client_set(private_data_t *);
int client_setg(private_data_t *);
int file_sets(private_data_t *, char);
int file_sets2(private_data_t *, char, int, int);

int start_neg(private_data_t *);
int stag_neg(private_data_t *);

int lockfile_remove(char *, char *, char *);
int neg(char *, char *, unsigned char *);
char * chack_lockfile(char *, char *, char *, char *, int *);
int lock_remove(char *);

char * file_send(int, char *, char *, int *, int, char);
char * file_send2(int, char *, char *, int *, int, char);
int log_out2(int, char *, char *, char *, char *, unsigned char *);
int fd_outopen(char *, FILE *);
int put_log(char *, char *, char*, unsigned char *);
int put_log2(int, char *, char*, unsigned char *);
char * filename_create(char *, char *, char *, char *);

int mail_time_getr(char [], int, char *);

int mail_grsend( char *, char *, char *, char *, char *, char *, char *, char *, char *);

int life_check(private_data_t *);

char * stat_check(char *, char *, int, int *);
